import { NextResponse } from "next/server"
import { writeFile } from "fs/promises"
import path from "path"
import { cookies } from "next/headers"

export async function POST(request: Request) {
  try {
    // Vérifier l'authentification et les autorisations
    // Récupérer l'utilisateur à partir des cookies
    const userCookie = cookies().get("user")?.value
    if (!userCookie) {
      return NextResponse.json({ error: "Non authentifié" }, { status: 401 })
    }

    const user = JSON.parse(userCookie)

    // Vérifier si l'utilisateur est un administrateur
    if (user.role !== "admin") {
      return NextResponse.json({ error: "Non autorisé" }, { status: 403 })
    }

    // Traiter la requête multipart/form-data
    const formData = await request.formData()
    const audioFile = formData.get("audio") as File
    const questionId = formData.get("questionId") as string

    if (!audioFile || !questionId) {
      return NextResponse.json({ error: "Fichier audio ou ID de question manquant" }, { status: 400 })
    }

    // Vérifier le type de fichier
    if (!audioFile.type.startsWith("audio/")) {
      return NextResponse.json({ error: "Le fichier doit être un fichier audio" }, { status: 400 })
    }

    // Créer un nom de fichier unique
    const fileName = `question_${questionId}_${Date.now()}${path.extname(audioFile.name)}`

    // Assurez-vous que le dossier existe
    const audioDir = path.join(process.cwd(), "public", "audio")

    // Convertir le fichier en buffer
    const buffer = Buffer.from(await audioFile.arrayBuffer())

    // Enregistrer le fichier
    await writeFile(path.join(audioDir, fileName), buffer)

    // URL publique du fichier
    const audioUrl = `/audio/${fileName}`

    // Note: Vous devrez peut-être adapter cette partie selon votre modèle de données
    // Si vous n'avez pas de table "question" dans votre base de données,
    // vous pourriez stocker ces informations ailleurs ou les gérer différemment

    /* 
    // Exemple de mise à jour dans la base de données
    await prisma.question.update({
      where: { id: questionId },
      data: { audio_url: audioUrl },
    })
    */

    return NextResponse.json({
      success: true,
      audioUrl,
    })
  } catch (error) {
    console.error("Erreur lors du téléchargement de l'audio:", error)
    return NextResponse.json({ error: "Erreur lors du téléchargement de l'audio" }, { status: 500 })
  }
}
